@@ -1,4 +1,4 @@
-#' Caterpillar plot with thick and thin CI
+ #' Caterpillar plot with thick and thin CI
 #'
 #' Caterpillar plots are plotted combining all chains for each parameter.
 #'
@@ -60,7 +60,8 @@ ggs_caterpillar <- function(D, family=NA, X=NA,
       if (length(names(D)!=0)) model.label <- names(D)[i]                   # get model labels from named list
 
       # Transform list elements into wide dfs with thick and thin limits
-      dcm <- rbind_list(dcm, ci(D[[i]]) %>% dplyr::mutate(Model=model.label))
+      dcm <- dplyr::bind_rows(dcm, ci(D[[i]]) %>%
+        dplyr::mutate(Model=model.label))
     }
 
   } else if (is.data.frame(D)) { # D is a data frame, and so a single model is passed
