@@ -29,24 +29,24 @@ ggs_geweke <- function(D, family=NA, frac1=0.1, frac2=0.5, shadow_limit=TRUE) {
   window.2 <- trunc(attributes(D)$nIterations * frac2):attributes(D)$nIterations
   D.geweke.first <- dplyr::mutate(dplyr::filter(D, Iteration <= max(window.1)), part="first")
   D.geweke.last <- dplyr::mutate(dplyr::filter(D, Iteration <= max(window.2)), part="last")
-  D.geweke <- rbind_list(D.geweke.first, D.geweke.last)
+  D.geweke <- dplyr::bind_rows(D.geweke.first, D.geweke.last)
   # Compute means, spectral densities and N's
   D.geweke <- D.geweke %>%
-    group_by (Parameter, Chain, part) %>%
+    dplyr::group_by (Parameter, Chain, part) %>%
     dplyr::summarize(m=mean(value), sde0f=sde0f(value), n=n())
   # Cast the dataframe in pieces to have the data arranged by parameter, chain
   # and first and last
   M <- D.geweke %>%
     dplyr::select(-sde0f, -n) %>%
-    ungroup() %>%
+    dplyr::ungroup() %>%
     tidyr::spread(part, m)
   N <- D.geweke %>%
     dplyr::select(-sde0f, -m) %>%
-    ungroup() %>%
+    dplyr::ungroup() %>%
     tidyr::spread(part, n)
   SDE0F <- D.geweke %>%
     dplyr::select(-m, -n) %>%
-    ungroup() %>%
+    dplyr::ungroup() %>%
     tidyr::spread(part, sde0f)
   # Reorganize the z scores
   Z <- data.frame(Parameter=M$Parameter, Chain=M$Chain,
